@@ -46,15 +46,11 @@ def get_models_training_report(models,tpu, n_class, traindata, steps_per_epoch,
 	return df
 
 
-if __name__ == "__main__":
-	pass
-else:
+if __name__ != "__main__":
 	#import os
 	#print("Installing the reqd libraries...\n")
 	#os.system("pip install tensorflow==2.2.0")
 	#os.system("pip install keras==2.4.3")
 	import tensorflow as tf
-	if tf.__version__ == '2.4.0':
-		pass
-	else:
-		print("Error! Tensorflow version Mismatch...")
\ No newline at end of file
+	if tf.__version__ != '2.4.0':
+		print("Error! Tensorflow version Mismatch...")
